==> ci-hotel_V1.0.2_20101221.zip: ci-hotel_V1.0.2_20101221/system/application/views/admin/roomtypes/add.php <==
<?php
include(dirname(__FILE__) . '/../header1.php');
?>
<link rel="stylesheet" href="<?php echo base_url() ?>js/jquery/themes/base/jquery.ui.all.css">
<script src="<?php echo base_url() ?>js/jquery/jquery-1.4.2.js"></script>
<script src="<?php echo base_url() ?>js/jquery/ui/jquery.ui.core.js"></script>
<script src="<?php echo base_url() ?>js/jquery/ui/jquery.ui.widget.js"></script>
<script src="<?php echo base_url() ?>js/jquery/ui/jquery.ui.datepicker.js"></script>
<script src="<?php echo base_url() ?>js/jquery/ui/i18n/jquery.ui.datepicker-ja.js"></script>
	<script>
	$(function() {
		$("#datepicker1").datepicker({dateFormat: 'yy-mm-dd'});
		$("#datepicker2").datepicker({dateFormat: 'yy-mm-dd'});
	});
	</script>
<link rel="stylesheet" href="<?php echo base_url() ?>css/ui.spinner.css">
<script type="text/javascript" src="<?php echo base_url() ?>js/jquery.ui-1.6rc2/ui/ui.core.js"></script>
<script type="text/javascript" src="<?php echo base_url() ?>js/jquery.ui-1.6rc2/ui/ui.spinner.js"></script>
    <script>
    $(document).ready(function(){
        $("#s1").spinner({max: 99, min: 1});
        $("#s2").spinner({max: 99, min: 1});
        $("#s3").spinner({max: 99, min: 1});
    });
    </script>
<?php
include(dirname(__FILE__) . '/../header2.php');
?>

<h2>部屋タイプの新規追加</h2>

<?php
if (isset($error) && count($error))
{
    echo '<div class="form_error"><ul>' . "\n";
    foreach ($error as $err)
    {
        echo "<li>" . $err . "</li>" . "\n";
    }
    echo '</ul></div>' . "\n";
}
?>

<?php echo form_open('admin/roomtypes/add'); ?>
<?php include('form.php') ?>
</form>

<?php
include(dirname(__FILE__) . '/../footer.php');
?>

==> ci-hotel_V1.2.0_20110206.zip: ci-hotel_1.2.0_20110206/system/application/views/admin/roomtypes/add.php <==
<?php
include(dirname(__FILE__) . '/../header1.php');
?>
<link rel="stylesheet" href="<?php echo base_url() ?>js/jquery/themes/base/jquery.ui.all.css">
<script src="<?php echo base_url() ?>js/jquery/jquery-1.4.2.js"></script>
<script src="<?php echo base_url() ?>js/jquery/ui/jquery.ui.core.js"></script>
<script src="<?php echo base_url() ?>js/jquery/ui/jquery.ui.widget.js"></script>
<script src="<?php echo base_url() ?>js/jquery/ui/jquery.ui.datepicker.js"></script>
<script src="<?php echo base_url() ?>js/jquery/ui/i18n/jquery.ui.datepicker-ja.js"></script>
	<script>
	$(function() {
		$("#datepicker1").datepicker({dateFormat: 'yy-mm-dd'});
		$("#datepicker2").datepicker({dateFormat: 'yy-mm-dd'});
	});
	</script>
<link rel="stylesheet" href="<?php echo base_url() ?>css/ui.spinner.css">
<script type="text/javascript" src="<?php echo base_url() ?>js/jquery.ui-1.6rc2/ui/ui.core.js"></script>
<script type="text/javascript" src="<?php echo base_url() ?>js/jquery.ui-1.6rc2/ui/ui.spinner.js"></script>
    <script>
    $(document).ready(function(){
        $("#s1").spinner({max: 99, min: 1});
        $("#s2").spinner({max: 99, min: 1});
        $("#s3").spinner({max: 99, min: 1});
    });
    </script>
<?php
include(dirname(__FILE__) . '/../header2.php');
?>

<h2>部屋タイプの新規追加</h2>

<?php
if (isset($error) && count($error))
{
    echo '<div class="form_error"><ul>' . "\n";
    foreach ($error as $err)
    {
        echo "<li>" . $err . "</li>" . "\n";
    }
    echo '</ul></div>' . "\n";
}
?>

<?php echo form_open('admin/roomtypes/add/' . $hotelid); ?>
<?php include('form.php') ?>
</form>

<?php
include(dirname(__FILE__) . '/../footer.php');
?>
